# Linear Normal model to analyse abundance indices of Thiof fish in Senegal
# Chapter  6

# R program used to generate data in a BUGS format
# from data in a table format

# The program essentially generates
# - the matrix of covariates X used for linear modeling Y = X * theta + eps
# - the Precision matrix P0 used for the Zellner prior on the parameters Theta

# -------------------------------------------------------------------------

library(rbugs)
library(boot)

# Load data

data <- read.table(file = "data_lm_AbundanceIndicesThiof_table.txt", header = T, sep = "")
data$CPUE <- data$Catches/data$Effort
n = length(data$Year)

# Used for predictive
years.pred <- min(data$Year):max(data$Year)
n.years <- length(years.pred)


# Constants common to all models
# ------------------------------------------

# tau ~ gamma(a,b)
a <- 1
b <- 1

# c : relative weight of the data vs prior
# c = 1 : same weight prior / data
# large c ==> high importance given to the data
c <- n

# Matrix of covariates X and prior Precision matrix for the prior on parameters Theta
# calculated for the model 1: log(CPUE) ~ Constant + Season + Zone + Year
# ------------------------------------------

dim_theta <- 6

theta0 <- rep(x=0, times = dim_theta)

X <- matrix(NA,n,dim_theta)
X[,1] <- rep(1,n)

S1 <- 1*(data$Season==1)
S2 <- 1*(data$Season==2)
X[,2] <- S1-S2

Z1 <- 1*(data$Zone==1)
Z2 <- 1*(data$Zone==2)
Z3 <- 1*(data$Zone==3)
Z4 <- 1*(data$Zone==4)
X[,3] <- Z1-Z4
X[,4] <- Z2-Z4
X[,5] <- Z3-Z4

X[,6] <- 1*data$Year

# X[,6] <- 1*data$Year*(data$Season==1)
# X[,7] <- 1*data$Year*(data$Season==2)

P0 <- t(X)%*%X

data <- list(	n=n, a = a, b = b, c = c, y = data$CPUE,
			theta0=theta0, P0 = P0, X = X, k = dim_theta,
			n.years = n.years, years.pred = years.pred)
file_to_save <- "data_lm_AbundanceIndicesThiof.txt"
genDataFile(data, file_to_save)      


                                                           